pub struct AnalysisResults(/* private fields */);Expand description
A set of analysis results.
If successfully created, the set of analysis results are guaranteed not to have any associated errors (but they may contain diagnostics).
Implementations
Sourceimpl AnalysisResults
impl AnalysisResults
Sourcepub fn try_new(
results: Vec<AnalysisResult>,
) -> Result<Self, NonEmpty<Arc<Error>>>
pub fn try_new( results: Vec<AnalysisResult>, ) -> Result<Self, NonEmpty<Arc<Error>>>
Attempts to create a new set of analysis results.
Returns any errors encountered during analysis. That being said, each analysis result may have diagnostics.
Sourcepub fn into_inner(self) -> Vec<AnalysisResult>
pub fn into_inner(self) -> Vec<AnalysisResult>
Consumes self and returns the inner vector of analysis results.
Sourcepub fn filter(
&self,
sources: &[&Source],
) -> impl Iterator<Item = &AnalysisResult>
pub fn filter( &self, sources: &[&Source], ) -> impl Iterator<Item = &AnalysisResult>
Attempts to find all analysis results that match any of the provided sources.
Sourcepub fn diagnostics(
&self,
) -> impl Iterator<Item = (Rc<String>, Rc<String>, &Diagnostic)>
pub fn diagnostics( &self, ) -> impl Iterator<Item = (Rc<String>, Rc<String>, &Diagnostic)>
Iterates over the diagnostics within the analysis result set.
The return type is an iterator that yields tuples that contain the following:
- The path to the file containing the diagnostic.
- The source of the file containing the diagnostic.
- A reference to the diagnostic itself.