Module inputs

Module inputs 

Inputs parsed in from the command line.

Re-exports

pub use file::InputFile;
pub use origin_paths::OriginPaths;

Modules

file
Input files parsed in from the command line.
origin_paths
The set of origin paths for each read input argument.

Structs

Inputs
A set of inputs parsed from the command line and compiled on top of one another.

Enums

Error
An error related to inputs.
Input
An input parsed from the command line.

Type Aliases

Result
A Result with an Error.