pub enum Error {
NotFound(PathBuf),
Path {
path: String,
error: Error,
},
Json(Error),
InvalidDir(PathBuf),
NonMapRoot(EvaluationPath),
Io {
path: EvaluationPath,
error: Error,
},
Reqwest {
path: EvaluationPath,
error: Error,
},
UnsupportedFileExt(EvaluationPath),
Yaml(Error),
}Expand description
An error related to a input file.
Variants
NotFound(PathBuf)
An input file specified by local path was not found.
Path
An error occurred parsing an input file path.
Json(Error)
An error occurring in serde_json.
InvalidDir(PathBuf)
An input file cannot be read from a directory.
NonMapRoot(EvaluationPath)
The input file did not contain a map at the root.
Io
Failed to read the contents of an input file due to I/O error.
Reqwest
Failed to read the contents of an input file due to reqwest error.
Fields

path: EvaluationPathThe path to the inputs file.
UnsupportedFileExt(EvaluationPath)
Neither JSON nor YAML could be parsed from the provided path.
Yaml(Error)
An error occurring in serde_yaml_ng.