pub struct InputFile;Expand description
An input file containing WDL values.
Implementations
Sourceimpl InputFile
impl InputFile
Sourcepub async fn read(path: &EvaluationPath) -> Result<Inputs>
pub async fn read(path: &EvaluationPath) -> Result<Inputs>
Reads an input file.
The file is attempted to be parsed based on its extension.
- If the input file is successfully parsed, it’s returned wrapped in
Ok. - If a deserialization error is encountered while parsing the JSON/YAML
file, an
Error::Json/Error::Yamlis returned respectively. - If no recognized extension is found, an
Error::UnsupportedFileExtis returned.