Module origin_paths

The set of origin paths for each read input argument.

An origin path is the associated directory for which each parsed command line argument is relative to. So, for example, arguments read in from files are relative to the directory the file lives within, whereas arguments provided on the command line are relative to the current working directory.

This mechanism ensures that, when files or directories are specified as inputs, we know the prefix to join to those paths to resolve the final location of each path.

Enums

OriginPaths
An associated set of path origins for a set of input keys.