pub enum OriginPaths {
Single(PathBuf),
Map(IndexMap<String, PathBuf>),
}Expand description
An associated set of path origins for a set of input keys.
This is useful when, for example, resolving all paths within an
Inputs to be relative to the input file from whence they
originated.
Variants
Single(PathBuf)
A single origin path for all inputs.
Map(IndexMap<String, PathBuf>)
A dynamic mapping of input keys to origin paths.
Implementations