Inputs parsed in from the command line.
Re-exports
pub use file::InputFile;pub use origin_paths::OriginPaths;
Modules
- file
- Input files parsed in from the command line.
- origin_
paths - The set of origin paths for each read input argument.
Structs
- Inputs
- A set of inputs parsed from the command line and compiled on top of one another.